@@ -1,9 +1,10 @@
+//go:build !windows
 // +build !windows
 
 package main
 
 // This file is part of goimapnotify
-// Copyright (C) 2017-2019  Jorge Javier Araya Navarro
+// Copyright (C) 2017-2021  Jorge Javier Araya Navarro
 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,10 +21,10 @@ package main
 
 import (
 	"fmt"
-	"log"
-	"os"
 	"os/exec"
 	"strings"
+
+	"github.com/sirupsen/logrus"
 )
 
 // PrepareCommand parse a string and return a command executable by Go
@@ -36,9 +37,11 @@ func PrepareCommand(command string, rsp IDLEEvent) *exec.Cmd {
 	}
 
 	commandsplt := append([]string{"sh", "-c"}, commandstr)
-	log.Printf("[DBG] Command: %s", strings.Join(commandsplt, " "))
+	logrus.Debugf("Command: %s", strings.Join(commandsplt, " "))
 	// #nosec
 	cmd := exec.Command(commandsplt[0], commandsplt[1:]...)
-	cmd.Stdout = os.Stdout
+	cmd.Stdout = nil
+	cmd.Stderr = nil
+
 	return cmd
 }
