@@ -1,7 +1,7 @@
 package main
 
 // This file is part of goimapnotify
-// Copyright (C) 2017-2019  Jorge Javier Araya Navarro
+// Copyright (C) 2017-2021  Jorge Javier Araya Navarro
 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ func PrepareCommand(command string, rsp IDLEEvent) *exec.Cmd {
 	}
 
 	commandsplt := append([]string{"cmd", "/c"}, commandstr)
-	log.Printf("[DBG] Command: %s", strings.Join(commandsplt, " "))
+	logrus.Debugf("Command: %s", strings.Join(commandsplt, " "))
 	// #nosec
 	cmd := exec.Command(commandsplt[0], commandsplt[1:]...)
 	cmd.Stdout = os.Stdout
