@@ -60,15 +60,24 @@ func main() {
 			getDefaultConfigPath(),
 			fmt.Sprintf("goimapnotify.%s", viper.SupportedExts[2]),
 		),
-		"Configuration file",
+		"Configuration file, supported formats: json, yaml/yml, toml",
 	)
 	list := flag.Bool("list", false, "List all mailboxes and exit")
 	loglevel := flag.String(
 		"log-level",
 		"info",
-		"change the logging level, possible values: error, warning/warn, info/information, debug",
+		"Change the logging level; possible values are: error, warn, info, debug",
+	)
+	wait := flag.Int(
+		"wait",
+		1,
+		"Delay in seconds between the IDLE event and the execution of the scripts",
+	)
+	dialRetries := flag.Int(
+		"dial-retry-attempts",
+		5,
+		"Number of attempts when connecting to an IMAP server, using exponential backoff",
 	)
-	wait := flag.Int("wait", 1, "Period in seconds between IDLE event and execution of scripts")
 
 	flag.Usage = usage
 
@@ -103,7 +112,7 @@ func main() {
 	quit := make(chan os.Signal, 1)
 	quitChan := make(chan struct{})
 
-	topConfig, err := loadConfiguration(*fileconf)
+	topConfig, err := loadConfiguration(*fileconf, *dialRetries)
 	if err != nil {
 		logrus.WithError(err).Fatalf("can't load the configuration %q", *fileconf)
 	}
@@ -115,7 +124,7 @@ func main() {
 
 	if *list {
 		for _, account := range topConfig.Configurations {
-			client, err := newClient(account)
+			client, err := newClient(account, *dialRetries)
 			if err != nil {
 				logrus.WithError(err).
 					WithField("account", account.Alias).
@@ -153,7 +162,7 @@ func main() {
 		*/
 		for _, account := range topConfig.Configurations {
 			for _, mailbox := range account.Boxes {
-				client, err := newIMAPIDLEClient(account)
+				client, err := newIMAPIDLEClient(account, *dialRetries)
 				if err != nil {
 					logrus.WithError(err).
 						WithField("account", account.Alias).
@@ -173,7 +182,7 @@ func main() {
 			l := logrus.WithField("alias", boxEvent.Mailbox.Alias).
 				WithField("mailbox", boxEvent.Mailbox.Mailbox)
 			l.Info("Restarting watcher for mailbox")
-			client, fErr := newIMAPIDLEClient(running.config[key])
+			client, fErr := newIMAPIDLEClient(running.config[key], *dialRetries)
 			if fErr != nil {
 				l.WithError(fErr).Fatal("Something went wrong creating IDLE client")
 			}
